@@ -1,11 +1,11 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 from pathlib import Path
 
 import pandas as pd
 import structlog
-from openstef_dbc.services.prediction_job import PredictionJobDataClass
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 
 from openstef.feature_engineering.feature_applicator import (
     OperationalPredictFeatureApplicator,
@@ -41,11 +41,10 @@ def create_basecase_forecast_pipeline(
     logger = structlog.get_logger(__name__)
 
     logger.info("Preprocessing data for basecase forecast")
-    # Validate and clean data - use a very long flatliner threshold.
-    # If a measurement was constant for a long period, a basecase should still be made.
-    validated_data = validation.validate(
-        pj["id"], input_data, flatliner_threshold=4 * 24 * 14 + 1
-    )
+    # Validate data
+    # Currently effectively disabled by giving None.
+    # We keep this step so it later can be filled using arguments defined in PJ
+    validated_data = validation.validate(pj["id"], input_data, flatliner_threshold=None)
 
     # Add features
     data_with_features = OperationalPredictFeatureApplicator(
@@ -58,7 +57,7 @@ def create_basecase_forecast_pipeline(
 
     # Similarly to the forecast pipeline, only try to make a forecast for moments in the future
     # TODO, do we want to be this strict on time window of forecast in this place?
-    # see issue https://github.com/alliander-opensource/openstef/issues/121
+    # see issue https://github.com/OpenSTEF/openstef/issues/121
     forecast_start, forecast_end = generate_forecast_datetime_range(data_with_features)
     forecast_input = data_with_features[forecast_start:forecast_end]
 
